package com.jnssd.controller;

import com.jnssd.model.Role;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Objects;

/**
 * <h3>spring-boot-openapi</h3>
 * <p>角色</p>
 *
 * @author zxj
 * @since 2023-10-12 16:32:38
 */
@Tag(name = "角色", description = "角色")
@RestController
@RequestMapping("/role")
public class RoleController {

    final static String SUCCESS_TEXT = "操作成功！";
    final static String FAIL_TEXT = "操作失败！";

    List<Role> list = new java.util.ArrayList<>();

    @GetMapping("/")
    @Operation(summary = "获取所有角色", description = "获取所有角色")
    public ResponseEntity<List<Role>> getAll() {
        return ResponseEntity.ok(list);
    }

    // 添加方法
    @PostMapping("add")
    @Operation(summary = "添加角色", description = "添加角色")
    public ResponseEntity<String> add(Role entity) {
        try {
            entity.setId(list.size() + 1);
            list.add(entity);
            return ResponseEntity.ok(SUCCESS_TEXT);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseEntity.status(400).body(FAIL_TEXT);
        }
    }

    // 添加方法
    @PutMapping("update")
    @Operation(summary = "修改角色", description = "修改角色")
    public ResponseEntity<Object> update(Role entity) {
        try {
            // 修改list下面的数据
            list.replaceAll((role) -> Objects.equals(role.getId(), entity.getId()) ? entity : role);

            return ResponseEntity.ok(SUCCESS_TEXT);
        } catch (Exception e) {
            return ResponseEntity.status(400).body(FAIL_TEXT);
        }
    }

    // 删除方法
    @DeleteMapping("delete")
    @Operation(summary = "删除角色", description = "删除角色")
    public ResponseEntity<String> delete(Role entity) {
        try {
            boolean result = list.removeIf(e -> Objects.equals(e.getId(), entity.getId()));
            return result ? ResponseEntity.ok(SUCCESS_TEXT) : ResponseEntity.status(400).body(FAIL_TEXT);
        } catch (Exception e) {
            return ResponseEntity.status(400).body(null);
        }
    }

    // 查询方法
    @GetMapping("query")
    @Operation(summary = "查询角色", description = "查询角色")
    public ResponseEntity<Object> query(Integer id) {
        try {
            Role role = (Role) list.stream().filter(e -> Objects.equals(e.getId(), id));
            // list 下查询
            return ResponseEntity.ok(role);
        } catch (Exception e) {
            return ResponseEntity.status(400).body(FAIL_TEXT);
        }
    }
}
