package com.jnssd.controller;

import com.jnssd.model.Menu;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Objects;

/**
 * <h3>spring-boot-openapi</h3>
 * <p>菜单</p>
 *
 * @author zxj
 * @since 2023-10-12 16:33:23
 */
@RestController
@RequestMapping("/menu")
@Api(tags = "菜单")
public class MenuController {

    final static String SUCCESS_TEXT = "操作成功！";
    final static String FAIL_TEXT = "操作失败！";

    List<Menu> list = new java.util.ArrayList<>();

    @GetMapping("/")
    @ApiOperation(value = "获取所有菜单", notes = "获取所有菜单")
    public ResponseEntity<List<Menu>> getAll() {
        return ResponseEntity.ok(list);
    }

    // 添加方法
    @PostMapping("add")
    @ApiOperation(value = "添加菜单", notes = "添加菜单")
    public ResponseEntity<String> add(Menu entity) {
        try {
            entity.setId(list.size() + 1);
            list.add(entity);
            return ResponseEntity.ok(SUCCESS_TEXT);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseEntity.status(400).body(FAIL_TEXT);
        }
    }

    // 添加方法
    @PutMapping("update")
    @ApiOperation(value = "修改菜单", notes = "修改菜单")
    public ResponseEntity<Object> update(Menu entity) {
        try {
            // 修改list下面的数据
            list.replaceAll((menu) -> Objects.equals(menu.getId(), entity.getId()) ? entity : menu);

            return ResponseEntity.ok(SUCCESS_TEXT);
        } catch (Exception e) {
            return ResponseEntity.status(400).body(FAIL_TEXT);
        }
    }

    // 删除方法
    @DeleteMapping("delete")
    @ApiOperation(value = "删除菜单", notes = "删除菜单")
    public ResponseEntity<String> delete(Menu entity) {
        try {
            boolean result = list.removeIf(e -> Objects.equals(e.getId(), entity.getId()));
            return result ? ResponseEntity.ok(SUCCESS_TEXT) : ResponseEntity.status(400).body(FAIL_TEXT);
        } catch (Exception e) {
            return ResponseEntity.status(400).body(null);
        }
    }

    // 查询方法
    @GetMapping("query")
    @ApiOperation(value = "查询菜单", notes = "查询菜单")
    public ResponseEntity<Object> query(Integer id) {
        try {
            Menu menu = (Menu) list.stream().filter(e -> Objects.equals(e.getId(), id));
            // list 下查询
            return ResponseEntity.ok(menu);
        } catch (Exception e) {
            return ResponseEntity.status(400).body(FAIL_TEXT);
        }
    }
}
