package com.jnssd.controller;

import com.jnssd.model.User;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Objects;

/**
 * <h3>spring-boot-openapi</h3>
 * <p>用户</p>
 *
 * @author zxj
 * @since 2023-10-12 16:30:04
 */
@RestController
@RequestMapping("/user")
@Api(tags = "用户")
public class UserController {

    final static String SUCCESS_TEXT = "操作成功！";
    final static String FAIL_TEXT = "操作失败！";

    List<User> list = new java.util.ArrayList<>();

    @GetMapping("/")
    @ApiOperation(value = "获取所有用户", notes = "获取所有用户")
    public ResponseEntity<List<User>> getAll() {
        return ResponseEntity.ok(list);
    }

    // 添加方法
    @PostMapping("add")
    @ApiOperation(value = "添加用户", notes = "添加用户")
    public ResponseEntity<String> add(User entity) {
        try {
            entity.setId(list.size() + 1);
            list.add(entity);
            return ResponseEntity.ok(SUCCESS_TEXT);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseEntity.status(400).body(FAIL_TEXT);
        }
    }

    // 添加方法
    @PutMapping("update")
    @ApiOperation(value = "修改用户", notes = "修改用户")
    public ResponseEntity<Object> update(User entity) {
        try {
            // 修改list下面的数据
            list.replaceAll((user) -> Objects.equals(user.getId(), entity.getId()) ? entity : user);

            return ResponseEntity.ok(SUCCESS_TEXT);
        } catch (Exception e) {
            return ResponseEntity.status(400).body(FAIL_TEXT);
        }
    }

    // 删除方法
    @DeleteMapping("delete")
    @ApiOperation(value = "删除用户", notes = "删除用户")
    public ResponseEntity<String> delete(User entity) {
        try {
            boolean result = list.removeIf(e -> Objects.equals(e.getId(), entity.getId()));
            return result ? ResponseEntity.ok(SUCCESS_TEXT) : ResponseEntity.status(400).body(FAIL_TEXT);
        } catch (Exception e) {
            return ResponseEntity.status(400).body(null);
        }
    }

    // 查询方法
    @GetMapping("query")
    @ApiOperation(value = "查询用户", notes = "查询用户")
    public ResponseEntity<Object> query(Integer id) {
        try {
            User user = (User) list.stream().filter(e -> Objects.equals(e.getId(), id));
            // list 下查询
            return ResponseEntity.ok(user);
        } catch (Exception e) {
            return ResponseEntity.status(400).body(FAIL_TEXT);
        }
    }
}
